@@ -58,7 +58,7 @@
   (set-statusbar-message (get-stock-no-string)))
 
 (define (get-stock-no-string)
-  (string-append (_"Stock left:  ") 
+  (string-append (_"Stock left:") " " 
 		 (number->string (length (get-cards 0)))))
 
 (define (next-card card-list number)
